#!/bin/env node
const {exec} = require('child_process')

const path = require('path')
const fse = require('fs-extra')
;(async _ => {
  const tempDir = path.resolve(__dirname, 'temp')
  if(!process.argv[2]) throw new Error('Please, specify an input file')
  if(!process.argv[3]) throw new Error('Please, specify an output directory')
  const inputFile = path.resolve(process.argv[2])
  const outDir = path.resolve(process.argv[3])
  console.log(inputFile, outDir)
  const originalPdfPath = path.resolve(__dirname, inputFile)
  const tempPdfPath = path.resolve(tempDir, 'test.pdf')
  if(await fse.exists(tempDir)) await fse.remove(tempDir)
  await fse.mkdir(tempDir)
  await fse.copy(originalPdfPath, tempPdfPath)
  await bash(`pdftohtml -c -stdout ${tempPdfPath}`, tempDir)
  const css = `
  .page{width: 30%}
  button {
    position: absolute;
    height: 50px;
    bottom: 0;
    z-index: 1;
    background-color: rgba(0,0,0,0.7);
    border: none;
    border-radius: 0;
    color: white;
    font-weight: bold;
    font-size: 40px;
    width:0;
    padding: 0;
    transition: 300ms;
    cursor: pointer;
    overflow: hidden;
  }
  button:hover {
    font-size: 50px;
  }
  .root:hover button {
    width: 50px;
  }
  .previous {left: 0;}
  .next {right: 0;}
  iframe {transform-origin: 0 0}
  .root {overflow: hidden; position: relative;}
  `
  const js =`
    let links = [];
    let currentPage = 0

    function next() {
      if(currentPage < links.length - 1) {
        const link = links[++currentPage]
        if(link) link.click()
      }
    }
    function previous() {
      if(currentPage > 0) {
        const link = links[--currentPage]
        link.click()
      }
    }

    setTimeout(_ => {
      const iframe =document.querySelector('iframe')
      const ifrm = iframe.contentWindow || iframe.contentDocument.document || iframe.contentDocument;
      // set = ifrm.document.querySelector('frameset').setAttribute('cols', '0, *')
    })

    setInterval(_ => {
      const iframe =document.querySelector('iframe')
      const ifrm = iframe.contentWindow || iframe.contentDocument.document || iframe.contentDocument;
      links = ifrm.document.querySelector('frame[name="links"]').contentWindow.document.querySelectorAll('a') 
      containerWidth = document.querySelector('.root').parentElement.offsetWidth
      containerHeight = document.querySelector('.root').parentElement.offsetHeight
      width = document.querySelector('iframe').offsetWidth
      height = document.querySelector('iframe').offsetHeight
      scale = Math.min( 
        containerWidth / width, 
        containerHeight / height 
      ); 
        
      const root = document.querySelector('.root')
      root.style.height = iframe.offsetHeight * scale + 'px'
      document.querySelector('iframe').style.transform = 'scale('+scale+')'
    }, 25)
  `
  await fse.writeFile(path.resolve(tempDir, 'index.html'), `
    <style>${css}</style>
    
    <div class="root" style="display:flex">
      <button class="previous" onclick="previous()">←</button>
      <div>
        <iframe src="./test.html" width="1020" height="1305"></iframe>
      </div>
      <button class="next" onclick="next()">→</button>
    </div>
    &nbsp;
    <script>${js}</script>
  `)
  await fse.move(path.resolve(tempDir), path.resolve(outDir), { overwrite: true })
})().catch(console.error)


function bash(cmd, cwd) {
  return new Promise((resolve, reject) => {
    exec(`cd ${cwd} && ${cmd}`, (err, stdout, stderr) => {
      if(err || stderr) return reject(err, stderr)
      return resolve(stdout)
    })
  });
}

